@@ -1,4 +1,5 @@
 use snafu::Snafu;
+use std::path::PathBuf;
 
 #[derive(Snafu, Debug)]
 #[snafu(visibility = "pub(crate)")]
@@ -7,19 +8,19 @@ pub enum DotsyError {
     TODO,
     #[snafu(display("Error: Failed to run shell command"))]
     FailedToRunCommand,
-    #[snafu(display("Error: Failed to unlink symlink {link}",link=link))]
-    Unlink { link: String },
+    #[snafu(display("Error: Failed to unlink symlink {link}",link=link.display()))]
+    Unlink { link: PathBuf },
     #[snafu(display("Error: config file was not found"))]
     NoConfigFile,
     #[snafu(display(
         "Error: we had some trouble linking files please check these paths: {from}, {to}",
-        from=from,
-        to=to
+        from=from.display(),
+        to=to.display()
     ))]
-    CouldntCreateSymLink { from: String, to: String },
+    CouldntCreateSymLink { from: PathBuf, to: PathBuf },
     #[snafu(display(
         "Error: we had some trouble the file or directory please check this path doesn't already exist: {file}",
-        file=file
+        file=file.display()
     ))]
-    FileAlreadyExists { file: String },
+    FileAlreadyExists { file: PathBuf },
 }
